@@ -16,7 +16,7 @@
 #' }
 credentials_gce <- function(scopes = "https://www.googleapis.com/auth/cloud-platform",
                             service_account = "default", ...) {
-  ui_line("trying credentials_gce()")
+  gargle_debug("trying {.fun credentials_gce}")
   if (!detect_gce() || is.null(scopes)) {
     return(NULL)
   }
@@ -122,12 +122,15 @@ gce_metadata_request <- function(path, stop_on_error = TRUE) {
 
   if (stop_on_error) {
     if (inherits(response, "try-error")) {
-      stop(paste0("Error fetching GCE metadata: ", attr(response, "condition")$message))
+      gargle_abort("
+        Error fetching GCE metadata: {attr(response, 'condition')$message}")
     } else if (httr::http_error(response)) {
-      stop(paste0("Error fetching GCE metadata: ", httr::http_status(response)$message))
+      gargle_abort("
+        Error fetching GCE metadata: {httr::http_status(response)$message}")
     }
     if (response$headers$`metadata-flavor` != "Google") {
-      stop(paste0("Error fetching GCE metadata: missing/invalid metadata-flavor header"))
+      gargle_abort("
+        Error fetching GCE metadata: missing/invalid metadata-flavor header")
     }
   }
   response
