@@ -25,7 +25,8 @@ oauth_app_from_json <- function(path,
   info <- json[["installed"]] %||% json[["web"]]
 
   if (!all(c("client_id", "client_secret") %in% names(info))) {
-    stop("Can't find 'client_id' and 'client_secret' in the JSON", call. = FALSE)
+    gargle_abort("
+      Can't find {sq('client_id')} and {sq('client_secret')} in the JSON")
   }
 
   httr::oauth_app(
